float4x4 wi: WorldInverse;          // обратная мировая матрица
float4x4 wvp: WorldViewProjection;  // world * view * projection (clip space)

// позиция ИС (world space)
float4 light : POSITION
<
	string Object = "PointLight";
	string UIName = "Позиция ИС";
	string Space = "World";	
> = {0, 10, 0, 1};
// цвет материала
float4 color 
<
	string UIName = "Цвет";
	string UIWidget = "Color";
> = {1, 1, 0, 1};

// текстура
texture diffuseTexture : DIFFUSE 
<
	string ResourceName = "default_color.dds";
	string UIName = "Диффузная текстура";
	string ResourceType = "2D";
>;
sampler2D diffuseSampler = sampler_state 
{
	Texture = <diffuseTexture>;
	MagFilter = Linear;
	MinFilter = Linear;
	MipFilter = Linear;
	AddressU = Clamp;
	AddressV = Clamp;
};

// данные которые придут в вершинный шейдер
struct vs_input
{
	float4 pos		:POSITION;	// позиция вершины (object space)
	float3 norm		:NORMAL;	// нормаль вершины (object space)
	float2 uv		:TEXCOORD0;	// текстурные координаты (texture space)
};
// данные которые придут в пиксельный шейдер
struct ps_input
{
	float4 pos		:POSITION;	// результирующая позиция вершины (clip space)
	float4 clr		:COLOR;		// цвет вершины
	float2 uv		:TEXCOORD0;	// // текстурные координаты (texture space)
};

ps_input mainVS(vs_input v)
{
	ps_input r;
	// позицию в clip space
	r.pos = mul(v.pos, wvp);
	// вычисляем освещенность точки
	float4 lo = mul(light, wi);  
	float4 ln = normalize(lo - v.pos);        
	r.clr = dot(ln.xyz, v.norm) * color;
	// передаем текстурные координаты
	r.uv = v.uv;
	return(r);
}

float4 mainPS(ps_input f) : COLOR
{
	float4 texel = tex2D(diffuseSampler, f.uv);
	return(f.clr * texel);
}

technique technique0 
{
	pass p0 
	{
		VertexShader = compile vs_3_0 mainVS();
		PixelShader = compile ps_3_0 mainPS();
	}
}